@@ -4,7 +4,8 @@
 ###################################################
 ### code chunk number 1: setup
 ###################################################
-	options(prompt = "R> ", continue = "+  ", width = 70, useFancyQuotes = FALSE)
+	options(prompt = "R> ", continue = "+  ", 
+			width = 70, useFancyQuotes = FALSE)
 	set.seed(123)
 
 
@@ -52,19 +53,11 @@ defaultMc<-new("markovchain")
 ###################################################
 ### code chunk number 7: intromcList
 ###################################################
-
 mcList<-new("markovchainList",markovchains=list(mcWeather, defaultMc), name="A list of Markov chains")
 
 
 ###################################################
-### code chunk number 8: showClassesAndMethods
-###################################################
-showMethods(class="markovchain")
-showMethods(class="markovchainList")
-
-
-###################################################
-### code chunk number 9: operations
+### code chunk number 8: operations
 ###################################################
 initialState<-c(0,1,0)
 after2Days<-initialState*(mcWeather*mcWeather)
@@ -74,7 +67,7 @@ after7Days
 
 
 ###################################################
-### code chunk number 10: operations2
+### code chunk number 9: operations2
 ###################################################
 initialState<-c(0,1,0)
 mcWeatherTransposed<-t(mcWeather)
@@ -85,41 +78,41 @@ after7Days
 
 
 ###################################################
-### code chunk number 11: otherMethods
+### code chunk number 10: otherMethods
 ###################################################
 states(mcWeather)
 dim(mcWeather)
 
 
 ###################################################
-### code chunk number 12: transProb
+### code chunk number 11: transProb
 ###################################################
 transitionProbability(mcWeather, "cloudy","rain")
 mcWeather[2,3]
 
 
 ###################################################
-### code chunk number 13: printAndShow
+### code chunk number 12: printAndShow
 ###################################################
 print(mcWeather)
 show(mcWeather)
 
 
 ###################################################
-### code chunk number 14: mcPlot
+### code chunk number 13: mcPlot
 ###################################################
 plotMc(mcWeather)
 
 
 ###################################################
-### code chunk number 15: exportImport
+### code chunk number 14: exportImport
 ###################################################
 mcDf<-as(mcWeather, "data.frame")
 mcNew<-as(mcDf, "markovchain")
 
 
 ###################################################
-### code chunk number 16: cchcMcList
+### code chunk number 15: cchcMcList
 ###################################################
 stateNames=c("H","I","D")
 Q0<-new("markovchain", states=stateNames, 
@@ -130,15 +123,22 @@ Q2<-new("markovchain", states=stateNames,
         transitionMatrix=matrix(c(0.3, 0.2, 0.5,0, 0.2, 0.8,0, 0, 1),byrow=TRUE,nrow=3), name="state t2")
 Q3<-new("markovchain", states=stateNames, transitionMatrix=matrix(c(0, 0, 1,0, 0, 1,0, 0, 1),byrow=TRUE, nrow=3), name="state t3")
 mcCCRC<-new("markovchainList",markovchains=list(Q0,Q1,Q2,Q3), name="Continuous Care Health Community")
+print(mcCCRC)
 
 
 ###################################################
-### code chunk number 17: cchcMcList2
+### code chunk number 16: cchcMcList2
 ###################################################
 mcCCRC[[1]]
 dim(mcCCRC)
 
 
+###################################################
+### code chunk number 17: conditionalDistr
+###################################################
+conditionalDistribution(mcWeather, "sunny")
+
+
 ###################################################
 ### code chunk number 18: steadyStates
 ###################################################
@@ -193,20 +193,51 @@ patientStates[1:10,]
 ###################################################
 ### code chunk number 23: fitMcbyMLE
 ###################################################
-weatherFittedMLE<-markovchainFit(data=weathersOfDays, method="mle")
+weatherFittedMLE<-markovchainFit(data=weathersOfDays, method="mle",name="Weather MLE")
 weatherFittedMLE$estimate
 
 
 ###################################################
-### code chunk number 24: fitMcbyBootStrap
+### code chunk number 24: fitMcbyLAPLACE
 ###################################################
-weatherFittedBOOT<-markovchainFit(data=weathersOfDays, method="bootstrap",nboot=50)
+weatherFittedLAPLACE<-markovchainFit(data=weathersOfDays, method="laplace",laplacian=0.01,name="Weather LAPLACE")
+weatherFittedLAPLACE$estimate
+
+
+###################################################
+### code chunk number 25: fitSequenceMatrix
+###################################################
+createSequenceMatrix(stringchar = weathersOfDays)
+
+
+###################################################
+### code chunk number 26: fitMcbyBootStrap
+###################################################
+weatherFittedBOOT<-markovchainFit(data=weathersOfDays, method="bootstrap",nboot=100)
 weatherFittedBOOT$estimate
 weatherFittedBOOT$standardError
 
 
 ###################################################
-### code chunk number 25: healthIns1
+### code chunk number 27: markovchainPredict
+###################################################
+predict(object=weatherFittedMLE$estimate,newdata=c("cloudy","sunny"),n.ahead=3)
+
+
+###################################################
+### code chunk number 28: markovchainListPredict
+###################################################
+predict(mcCCRC,newdata=c("H","H"),n.ahead=5)
+
+
+###################################################
+### code chunk number 29: markovchainListPredict2
+###################################################
+predict(mcCCRC,newdata=c("H","H"),n.ahead=5, continue=TRUE)
+
+
+###################################################
+### code chunk number 30: healthIns1
 ###################################################
 
 mcHI=new("markovchain", states=c("active", "disable", "withdrawn", "death"),
@@ -221,7 +252,7 @@ benefitVector=as.matrix(c(0,0,500,1000))
 
 
 ###################################################
-### code chunk number 26: healthIns2
+### code chunk number 31: healthIns2
 ###################################################
 T0=t(as.matrix(c(1,0,0,0)))
 T1=T0*mcHI
@@ -230,19 +261,20 @@ T3=T2*mcHI
 
 
 ###################################################
-### code chunk number 27: healthIns3
+### code chunk number 32: healthIns3
 ###################################################
-PVFB=T0%*%benefitVector*1.05^-0+T1%*%benefitVector*1.05^-1+T2%*%benefitVector*1.05^-2+T3%*%benefitVector*1.05^-3
+PVFB=T0%*%benefitVector*1.05^-0+T1%*%benefitVector*1.05^-1+
+		T2%*%benefitVector*1.05^-2+T3%*%benefitVector*1.05^-3
 
 
 ###################################################
-### code chunk number 28: healthIns4
+### code chunk number 33: healthIns4
 ###################################################
 P=PVFB/(T0[1]*1.05^-0+T1[1]*1.05^-1+T2[1]*1.05^-2)
 
 
 ###################################################
-### code chunk number 29: healthIns5
+### code chunk number 34: healthIns5
 ###################################################
 PVFB=(T2%*%benefitVector*1.05^-1+T3%*%benefitVector*1.05^-2)
 PVFP=P*(T1[1]*1.05^-0+T2[1]*1.05^-1)
@@ -250,3 +282,117 @@ V=PVFB-PVFP
 V
 
 
+###################################################
+### code chunk number 35: weatPred1
+###################################################
+
+mcWP=new("markovchain", states=c("rainy", "nice", "snowy"),
+         transitionMatrix=matrix(c(0.5, 0.25, 0.25,
+                                   0.5, 0, 0.5,
+                                   0.25,0.25,0.5), byrow=TRUE, nrow=3))
+
+
+###################################################
+### code chunk number 36: weatPred2
+###################################################
+W0=t(as.matrix(c(0,1,0)))
+W1=W0*mcWP
+W1
+
+W2=W0*(mcWP^2)
+W2
+
+W3=W0*(mcWP^3)
+W3
+
+
+###################################################
+### code chunk number 37: weatPred3
+###################################################
+W7=W0*(mcWP^7)
+W7
+
+
+###################################################
+### code chunk number 38: weatPred4
+###################################################
+q=steadyStates(mcWP)
+q
+
+
+###################################################
+### code chunk number 39: weatPred5
+###################################################
+R0=t(as.matrix(c(1,0,0)))
+R7=W0*(mcWP^7)
+R7
+
+S0=t(as.matrix(c(0,0,1)))
+R7=W0*(mcWP^7)
+R7
+
+
+###################################################
+### code chunk number 40: Alofi1
+###################################################
+data(rain, package="markovchain")
+table(rain$rain)
+
+
+###################################################
+### code chunk number 41: Alofi2
+###################################################
+mcAlofi<-markovchainFit(data=rain$rain, name="Alofi MC")$estimate
+mcAlofi
+
+
+###################################################
+### code chunk number 42: Alofi3
+###################################################
+steadyStates(mcAlofi)
+
+
+###################################################
+### code chunk number 43: preproglucacon1
+###################################################
+data(preproglucacon, package="markovchain")
+
+
+###################################################
+### code chunk number 44: preproglucacon2
+###################################################
+mcProtein<-markovchainFit(preproglucacon$preproglucacon, name="Preproglucacon MC")$estimate
+
+
+###################################################
+### code chunk number 45: epid1
+###################################################
+craigSendiMatr<-matrix(c(682,33,25,
+              154,64,47,
+              19,19,43), byrow=T,nrow=3)
+hivStates<-c("0-49", "50-74", "75-UP")
+rownames(craigSendiMatr)<-hivStates
+colnames(craigSendiMatr)<-hivStates
+craigSendiTable<-as.table(craigSendiMatr)
+mcM6<-as(craigSendiTable,"markovchain")
+mcM6@name="Zero-Six month CD4 cells transition"
+mcM6
+
+
+###################################################
+### code chunk number 46: epid2
+###################################################
+autov=eigen(mcM6@transitionMatrix)
+D=diag(autov$values)
+
+
+###################################################
+### code chunk number 47: epid3
+###################################################
+P=autov$vectors 
+P%*%D%*%solve(P)
+d=D^(1/6)
+M=P%*%d%*%solve(P)
+mcM1<-new("markovchain",transitionMatrix=M,states=hivStates)
+
+
